@@ -2,7 +2,7 @@ import json
 import os
 import shutil
 import subprocess
-
+from loguru import logger
 import hvac
 import requests
 import tldextract
@@ -341,6 +341,7 @@ class RundeckJobs(object):
                                            execution_mode=execution_mode, deployment_environment=deployment_environment,
                                            deployment_action=deployment_action)
 
+    @logger.catch
     def nextjs_build(
             self,
             pg_user: str = os.environ.get(
@@ -383,7 +384,6 @@ class RundeckJobs(object):
         fqdn = "{fqdn}"
         sld = "{sld}"
         project_name = "{organization}"
-        deployment_action = "{deployment_action}"
         git_domain = "{git_domain}"
         git_reponame = "{git_reponame}"
         git_branch = "{git_branch}"
@@ -399,12 +399,12 @@ class RundeckJobs(object):
         os.environ["TF_REGISTRY_DISCOVERY_RETRY"] = "10"
         os.environ["TF_REGISTRY_CLIENT_TIMEOUT"] = "60"
         os.environ["TF_IN_AUTOMATION"] = "true"
-        os.environ["TF_PLUGIN_CACHE_DIR"] = "$HOME/.terraform.d/plugin-cache"
+        os.environ["TF_PLUGIN_CACHE_DIR"] = "~/.terraform.d/plugin-cache"
         os.environ["TF_DATA_DIR"] = config_dir_location
 
         # shutil.copytree(f"{terraform_code_dir}/", f"{config_dir_location}/")
-        if not os.path.exists("$HOME/.terraform.d/plugin-cache"):
-            os.makedirs("$HOME/.terraform.d/plugin-cache")
+        if not os.path.exists("~/.terraform.d/plugin-cache"):
+            os.makedirs("~/.terraform.d/plugin-cache")
         self.run_command(["terraform", "init", "-input=false", "-reconfigure", "-force-copy",
                           f"-backend-config", backend_config_file_location],
                          cwd=terraform_code_dir, check=True)
